@@ -469,6 +469,8 @@ def close_dialog_and_quit(widget, screenshot: bool = False) -> None:
         wname = widget.objectName()
         if screenshot and wname and widget.isVisible():  # pragma: no cover
             grab_save_window(widget, wname.lower())
+        else:
+            QW.QApplication.processEvents()
         if execenv.accept_dialogs:
             widget.accept()
         else:
@@ -507,13 +509,13 @@ def qt_app_context(exec_loop: bool = False) -> Generator[QW.QApplication, None,
         if execenv.unattended:  # pragma: no cover
             if execenv.delay > 0:
                 mode = "Screenshot" if execenv.screenshot else "Unattended"
-                message = f"{mode} mode (delay: {execenv.delay}s)"
-                msec = execenv.delay * 1000 - 200
+                message = f"{mode} mode (delay: {execenv.delay}ms)"
+                msec = execenv.delay - 200
                 for widget in QW.QApplication.instance().topLevelWidgets():
                     if isinstance(widget, QW.QMainWindow):
                         widget.statusBar().showMessage(message, msec)
             QC.QTimer.singleShot(
-                execenv.delay * 1000,
+                execenv.delay,
                 lambda: close_widgets_and_quit(screenshot=execenv.screenshot),
             )
         if exec_loop and not exception_occured:
@@ -534,7 +536,7 @@ def exec_dialog(dlg: QW.QDialog) -> int:
     """
     if execenv.unattended:
         QC.QTimer.singleShot(
-            execenv.delay * 1000,
+            execenv.delay,
             lambda: close_dialog_and_quit(dlg, screenshot=execenv.screenshot),
         )
     delete_later = not dlg.testAttribute(QC.Qt.WA_DeleteOnClose)
