@@ -7,18 +7,22 @@ guidata.widgets.console
 This package provides a Python console widget.
 
 .. autoclass:: Console
+    :show-inheritance:
+    :members:
 
 .. autoclass:: DockableConsole
+    :show-inheritance:
+    :members:
 
 """
 
 from qtpy.QtCore import Qt
 
-from guidata.widgets.console.internalshell import InternalShell
-from guidata.qtwidgets import DockableWidgetMixin
-from guidata.qthelpers import win32_fix_title_bar_background
-from guidata.configtools import get_font
 from guidata.config import CONF, _
+from guidata.configtools import get_font
+from guidata.qthelpers import win32_fix_title_bar_background
+from guidata.widgets.console.internalshell import InternalShell
+from guidata.widgets.dockable import DockableWidgetMixin
 
 
 class Console(InternalShell):
