@@ -21,21 +21,24 @@ import sys
 import threading
 from time import time
 
+from qtpy.QtCore import QEventLoop, QObject, Signal, Slot
+from qtpy.QtWidgets import QMessageBox
+
 from guidata.config import CONF, _
-from guidata.qthelpers import create_action, get_std_icon, is_dark_mode
-from guidata.utils import getcwd_or_home, run_program
+from guidata.configtools import get_icon
+from guidata.qthelpers import add_actions, create_action, get_std_icon, is_dark_mode
+from guidata.utils.misc import getcwd_or_home, run_program
+from guidata.widgets import about
 from guidata.widgets.console.dochelpers import getargtxt, getdoc, getobjdir, getsource
 from guidata.widgets.console.interpreter import Interpreter
 from guidata.widgets.console.shell import PythonShellWidget
-from qtpy.QtCore import QEventLoop, QObject, Signal, Slot
-from qtpy.QtWidgets import QMessageBox
 
 
 def create_banner(message):
     """Create internal shell banner"""
     system = platform.system()
     if message is None:
-        bitness = 64 if sys.maxsize > 2 ** 32 else 32
+        bitness = 64 if sys.maxsize > 2**32 else 32
         return "Python %s %dbits [%s]" % (platform.python_version(), bitness, system)
     else:
         return message
@@ -280,7 +283,7 @@ class InternalShell(PythonShellWidget):
         self.setFocus()
         self.input_mode = True
         self.input_loop = QEventLoop()
-        self.input_loop.exec_()
+        self.input_loop.exec()
         self.input_loop = None
 
     def end_input(self, cmd):
@@ -293,18 +296,24 @@ class InternalShell(PythonShellWidget):
     def setup_context_menu(self):
         """Reimplement PythonShellWidget method"""
         PythonShellWidget.setup_context_menu(self)
-        self.help_action = create_action(
+        help_action = create_action(
             self,
             _("Help..."),
             icon=get_std_icon("DialogHelpButton"),
             triggered=self.help,
         )
-        self.menu.addAction(self.help_action)
+        about_action = create_action(
+            self,
+            _("About..."),
+            icon=get_icon("guidata.svg"),
+            triggered=about.show_about_dialog,
+        )
+        add_actions(self.menu, (None, help_action, about_action))
 
     @Slot()
     def help(self):
         """Help on Spyder console"""
-        QMessageBox.about(
+        QMessageBox.information(
             self,
             _("Help"),
             """<b>%s</b>
@@ -323,7 +332,6 @@ class InternalShell(PythonShellWidget):
                 _("Remove references:"),
                 _("System commands:"),
                 _("Python help:"),
-                _("GUI-based editor:"),
             ),
         )
 
@@ -364,7 +372,7 @@ class InternalShell(PythonShellWidget):
             t0 = time()
             for _ in range(10):
                 self.execute_command(command)
-            self.insert_text(u"\n<Δt>=%dms\n" % (1e2 * (time() - t0)))
+            self.insert_text("\n<Δt>=%dms\n" % (1e2 * (time() - t0)))
             self.new_prompt(self.interpreter.p1)
         else:
             self.execute_command(command)
